Module: Asposeslidesjava::AddingLineShape

Defined in:
lib/asposeslidesjava/Shapes/addinglineshape.rb

Instance Method Summary collapse

Instance Method Details

#add_arrow_lineObject



30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/asposeslidesjava/Shapes/addinglineshape.rb', line 30

def add_arrow_line()
    data_dir = File.dirname(File.dirname(File.dirname(File.dirname(__FILE__)))) + '/data/Shapes/'
            
    # Create an instance of Presentation class

    pres = Rjb::import('com.aspose.slides.Presentation').new

    # Get the first slide

    sld = pres.getSlides().get_Item(0)

    # Add an autoshape of type line

    shp = sld.getShapes().addAutoShape(Rjb::import('com.aspose.slides.ShapeType').Line, 50, 150, 300, 0)

    # Apply some formatting on the line

    shp.getLineFormat().setStyle(Rjb::import('com.aspose.slides.LineStyle').ThickBetweenThin)
    shp.getLineFormat().setWidth(10)

    shp.getLineFormat().setDashStyle(Rjb::import('com.aspose.slides.LineDashStyle').DashDot)

    shp.getLineFormat().setBeginArrowheadLength(Rjb::import('com.aspose.slides.LineArrowheadLength').Short)
    shp.getLineFormat().setBeginArrowheadStyle(Rjb::import('com.aspose.slides.LineArrowheadStyle').Oval)

    shp.getLineFormat().setEndArrowheadLength(Rjb::import('com.aspose.slides.LineArrowheadLength').Long)
    shp.getLineFormat().setEndArrowheadStyle(Rjb::import('com.aspose.slides.LineArrowheadStyle').Triangle)

    shp.getLineFormat().getFillFormat().setFillType(Rjb::import('com.aspose.slides.FillType').Solid)
    shp.getLineFormat().getFillFormat().getSolidFillColor().setColor(Rjb::import('java.awt.Color').new(Rjb::import('com.aspose.slides.PresetColor').Maroon))


    # Write the presentation as a PPTX file 

    save_format = Rjb::import('com.aspose.slides.SaveFormat')
    pres.save(data_dir + "ArrowShape.pptx", save_format.Pptx)

    puts "Added arrow shape line to slide, please check the output file."
end

#add_plain_lineObject



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
# File 'lib/asposeslidesjava/Shapes/addinglineshape.rb', line 11

def add_plain_line()
    data_dir = File.dirname(File.dirname(File.dirname(File.dirname(__FILE__)))) + '/data/Shapes/'
            
    # Create an instance of Presentation class

    pres = Rjb::import('com.aspose.slides.Presentation').new

    # Get the first slide

    sld = pres.getSlides().get_Item(0)

    # Add an autoshape of type line

    sld.getShapes().addAutoShape(Rjb::import('com.aspose.slides.ShapeType').Line, 50, 150, 300, 0)

    # Write the presentation as a PPTX file 

    save_format = Rjb::import('com.aspose.slides.SaveFormat')
    pres.save(data_dir + "LineShape.pptx", save_format.Pptx)

    puts "Added plain line to slide, please check the output file."
end

#initializeObject



3
4
5
6
7
8
9
# File 'lib/asposeslidesjava/Shapes/addinglineshape.rb', line 3

def initialize()
    # Adding Plain Line to Slide

    add_plain_line()

    # Adding Arrow Shaped Line to Slide

    add_arrow_line()
end